#!/usr/bin/env node

// Connect to *LOCAL database and set system naming convention.
// The job's library list will be used to resolve objects in SQL statements. 
var db2i = require("idb-connector");
var dbconn = new db2i.dbconn();
dbconn.conn("*LOCAL");

// Same as naming = *SYS in RPG
dbconn.setConnAttr(db2i.SQL_ATTR_DBC_SYS_NAMING, db2i.SQL_TRUE);

// Create an Excel workbook with one worksheet named "Orders".
var Excel = require("exceljs");
var workbook = new Excel.Workbook();
var worksheet = workbook.addWorksheet("Orders");

// Add column definitions to the worksheet.
// The column keys are named after the DB2 column names.
worksheet.columns = [
    { header: "Order #", key: "ORDERREF", width: 9 },
    { header: "Line #", key: "ORDERLINE", width: 7, style: { numFmt: "0" } },
    { header: "Product #", key: "PRODREF", width: 15 },
    { header: "Ordered Qty", key: "ORDERQTY", width: 12, style: { numFmt: "0" }  },
    { header: "Extended Amount", key: "SALETOTAL", width: 17, style: { numFmt: "$#,##0.00_);[Red]($#,##0.00)" } }
];
worksheet.getRow(1).font = { name: "Calibri", size: 11, bold: true };

// Run SQL statement to fetch records from DB2 "sales order detail" table.
var stm = new db2i.dbstmt(dbconn);
var sql = "select orderref, orderline, prodref, orderqty, saletotal from salesdtl";

stm.exec(sql, function(rs) {
  rs.forEach(function(row) {
    
    // The database driver returns all columns as JS strings.
    // Cast numeric fields to Number so that Excel number formatting will be applied properly.
    row.ORDERLINE = Number(row.ORDERLINE);
    row.ORDERQTY = Number(row.ORDERQTY);
    row.SALETOTAL = Number(row.SALETOTAL);
    
    // Add each row in the result set to the worksheet. 
    worksheet.addRow(row);
  });
  
  // Write the worksheet to the file system, in the current working directory.
  workbook.xlsx.writeFile("orders.xlsx");
});
